@@ -1090,7 +1090,9 @@ Logger.stdSerializers.req = function (req) {
         return req;
     return {
         method: req.method,
-        url: req.url,
+        // Accept `req.originalUrl` for expressjs usage.
+        // https://expressjs.com/en/api.html#req.originalUrl
+        url: req.originalUrl || req.url,
         headers: req.headers,
         remoteAddress: req.connection.remoteAddress,
         remotePort: req.connection.remotePort
